pub struct DirectMessageReceiver { /* private fields */ }Expand description
Receiver for direct messages.
This is a wrapper around a broadcast receiver that provides a cleaner API. Multiple receivers can be created to process messages in parallel.
Implementations
Sourceimpl DirectMessageReceiver
impl DirectMessageReceiver
Sourcepub async fn recv(&mut self) -> Option<DirectMessage>
pub async fn recv(&mut self) -> Option<DirectMessage>
Receive the next direct message.
Returns None if the channel is closed.
Sourcepub fn try_recv(&mut self) -> Option<DirectMessage>
pub fn try_recv(&mut self) -> Option<DirectMessage>
Try to receive a message without blocking.
Returns None if no message is available or channel is closed.